package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.QuoteCraft;

/**
 * 项目报价--服务工艺Mapper接口
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
public interface QuoteCraftMapper 
{
    /**
     * 查询项目报价--服务工艺
     * 
     * @param id 项目报价--服务工艺主键
     * @return 项目报价--服务工艺
     */
    public QuoteCraft selectQuoteCraftById(Long id);

    /**
     * 查询项目报价--服务工艺列表
     * 
     * @param quoteCraft 项目报价--服务工艺
     * @return 项目报价--服务工艺集合
     */
    public List<QuoteCraft> selectQuoteCraftList(QuoteCraft quoteCraft);

    /**
     * 新增项目报价--服务工艺
     * 
     * @param quoteCraft 项目报价--服务工艺
     * @return 结果
     */
    public int insertQuoteCraft(QuoteCraft quoteCraft);

    /**
     * 修改项目报价--服务工艺
     * 
     * @param quoteCraft 项目报价--服务工艺
     * @return 结果
     */
    public int updateQuoteCraft(QuoteCraft quoteCraft);

    /**
     * 删除项目报价--服务工艺
     * 
     * @param id 项目报价--服务工艺主键
     * @return 结果
     */
    public int deleteQuoteCraftById(Long id);

    /**
     * 批量删除项目报价--服务工艺
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteQuoteCraftByIds(Long[] ids);
}
